/************************************************************************/
/*                                                                      */
/*         XX      XX W           W  III  NN    N    GGGG               */
/*           XX  XX    W         W    I   N N   N   G                   */
/*             XX       W   W   W     I   N  N  N   G  GGG              */
/*           XX  XX      W W W W      I   N   N N   G    G              */
/*         XX      XX     W   W      III  N    NN    GGGG               */
/*                                                                      */
/*  QtAirfoil Version 0.1        U.Lehnert                   3 /2010    */
/*                                                                      */
/*  Berechnung der Skelettlinie von Tragflügel-Profilen,                */
/*  deren aerodynamischen Kenngrößen                                    */
/*  und deren Unterteilung in Segmente zur Benutzung mit XWing          */
/*                                                                      */
/************************************************************************/


/*

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

#include <QtGui>

#include "diagramscene.h"

DiagramScene::DiagramScene(QObject *parent)
    : QGraphicsScene(parent)
{
    line = 0;
    myLineColor = Qt::black;
}

void DiagramScene::setLineColor(const QColor &color)
{
    myLineColor = color;
}

void DiagramScene::plotSpline2D(Spline2D *spline)
{
  int nn=spline->length();
  QLineF *line= new QLineF();
  for (int i=1; i<20*(nn-1)+1; i++) {
    line->setLine(1000.0*spline->fx(0.05*(double)(i-1)),
                 -1000.0*spline->fy(0.05*(double)(i-1)),
                  1000.0*spline->fx(0.05*(double)i),
                 -1000.0*spline->fy(0.05*(double)i));
    addLine(*line);
  };
}

void DiagramScene::plotAirfoil(Airfoil *af)
{
  QLineF *line= new QLineF();
  int np=af->npoints();
  addEllipse(1000.0*af->px(0)-2.0,-1000.0*af->py(0)-2.0,4.0,4.0, QPen(Qt::black));
  for (int i=1; i<np; i++) {
    line->setLine(1000.0*af->px(i-1),-1000.0*af->py(i-1),
                  1000.0*af->px(i),-1000.0*af->py(i));
    addLine(*line, QPen(Qt::blue));
    addEllipse(1000.0*af->px(i)-2.0,-1000.0*af->py(i)-2.0,4.0,4.0, QPen(Qt::black));
  };
  addLine(0.0, 0.0, 1000.0, 0.0, QPen(Qt::green));
  addLine(0.0, -200.0, 0.0, 200.0, QPen(Qt::green));
  plotSpline2D(af->outline);
}

void DiagramScene::plotCamberline(Camberline *cl)
{
  QLineF *line= new QLineF();
  int np=cl->npoints();
  for (int i=1; i<np; i++) {
    line->setLine(1000.0*cl->xpoint(i-1),-1000.0*cl->ypoint(i-1),
                  1000.0*cl->xpoint(i),-1000.0*cl->ypoint(i));
    addLine(*line, QPen(Qt::red,0.0,Qt::SolidLine,Qt::RoundCap,Qt::RoundJoin));
  };
}

void DiagramScene::plotPaneling(Camberline *cl)
{
  QLineF *line= new QLineF();
  int np=cl->npoints();
  for (int i=1; i<np; i++) {
    line->setLine(1000.0*cl->xpoint(i-1),-1000.0*cl->ypoint(i-1),
                  1000.0*cl->xpoint(i),-1000.0*cl->ypoint(i));
    addLine(*line, QPen(Qt::red,0.0,Qt::SolidLine,Qt::RoundCap,Qt::RoundJoin));
  };
  for (int i=1; i<np-1; i++) {
    addEllipse(1000.0*cl->xpoint(i)-2.0,-1000.0*cl->ypoint(i)-2.0,4.0,4.0, QPen(Qt::red));
  };
}