/************************************************************************/
/*                                                                      */
/*         XX      XX W           W  III  NN    N    GGGG               */
/*           XX  XX    W         W    I   N N   N   G                   */
/*             XX       W   W   W     I   N  N  N   G  GGG              */
/*           XX  XX      W W W W      I   N   N N   G    G              */
/*         XX      XX     W   W      III  N    NN    GGGG               */
/*                                                                      */
/*  QtAirfoil Version 0.1        U.Lehnert                   3 /2010    */
/*                                                                      */
/*  Berechnung der Skelettlinie von Tragflügel-Profilen,                */
/*  deren aerodynamischen Kenngrößen                                    */
/*  und deren Unterteilung in Segmente zur Benutzung mit XWing          */
/*                                                                      */
/************************************************************************/


/*

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui>
#include <QMainWindow>
#include "diagramscene.h"

class Airfoil;
class DiagramScene;

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow();

protected:
    void closeEvent(QCloseEvent *event);

private slots:

    // open a new airfoil datafile
    void open();
    
    // show "about" dialog 
    void about();
    
    // recompute the camber line paneling
    // and regenerate the display
    void panelingChanged();

    // modify the camber line to match the prescribed
    // values of the aerodynamic coefficients
    void doModify();

private:
    void createActions();
    void createMenus();
    void createStatusBar();
    void createGridGroupBox();
    void createPanelingGroup();
    void createModifyGroup();

    void loadFile(const QString &fileName);
    void setCurrentFile(const QString &fileName);
    // recompute the camber line paneling
    // and regenerate the display
    void panelingRegenerateDisplay();
    
    QString strippedName(const QString &fullFileName);
    QString curFile;

    QGroupBox *gridGroupBox;
    QTextEdit *parameterDisplay;
    QGroupBox *panelingGroup;
    QTextEdit *panelingDisplay;
    QGroupBox *modifyGroup;
    QTextEdit *camberlineDisplay;

    QGridLayout *layout;
    DiagramScene *canvas;
    QGraphicsView *view;

    bool afValid;
    Airfoil *curAirfoil;
    
    QSpinBox *npanSpinBox;
    QDoubleSpinBox *ledSpinBox;
    QDoubleSpinBox *tedSpinBox;
    QDoubleSpinBox *alpha0SpinBox;
    QDoubleSpinBox *cm0SpinBox;
    QPushButton *modifyButton;
    
    Camberline *curCL;         // 200 panel camberline for current airfoil
    Camberline *panCL;         // camberline with actual paneling
    
    double cur_cl0;            // lift at zero angla of attack
    double cur_alfa0;          // angle of attack for zero lift in radian
    double cur_cm0;            // momentum
    double cur_dclda;          // lift slope in 1/radian
    double cur_asf;            // angle of attack for suction-free entrance
    double cur_clsf;           // lift coefficient for suction-free entrance

    QMenu *fileMenu;
    QMenu *helpMenu;
    QAction *newAct;
    QAction *openAct;
    QAction *exitAct;
    QAction *aboutAct;
    QAction *aboutQtAct;

};

#endif
